@@ -9,8 +9,8 @@ VE.Jk.CBS.HT.Ratio <- function(VecY.s, VecX.s, VecPk.s, MatPkl.s)
   DimMatC                             <- as.integer(DimMat[2])
   if(DimMatR != DimMatC              ){stop("MatPkl.s must be a square matrix. Number of rows and columns has to be equal.")}
   n                                   <- length(VecY.s)
-  if(n != as.integer(length(VecPk.s))){stop("The lengths of VecY.s and VecPk.s are different.")                             }
-  if(n != as.integer(length(VecX.s)) ){stop("The lengths of VecY.s and VecX.s are different.")                              }
+  if(n != length(VecPk.s)            ){stop("The lengths of VecY.s and VecPk.s are different.")                             }
+  if(n != length(VecX.s)             ){stop("The lengths of VecY.s and VecX.s are different.")                              }
   if(n != DimMatR                    ){stop("The lengths of VecY.s, VecPk.s and dimensions of MatPkl.s are different.")     }
   if(any(is.na(VecPk.s))             ){stop("There are missing values in VecPk.s.")                                         }
   if(any(VecPk.s<=0|VecPk.s>1)       ){stop("There are invalid values in VecPk.s.")                                         }
@@ -18,7 +18,7 @@ VE.Jk.CBS.HT.Ratio <- function(VecY.s, VecX.s, VecPk.s, MatPkl.s)
   if(any(MatPkl.s<=0|MatPkl.s>1)     ){stop("There are invalid values in MatPkl.s.")                                        }
   if(any(is.na(VecY.s))              ){stop("There are missing values in VecY.s.")                                          }
   if(any(is.na(VecX.s))              ){stop("There are missing values in VecX.s.")                                          }
-  if(any(VecX.s==0)                  ){stop("There are zero values in VecX.s. Division by zero is undefined.")              }
+  if(any(VecX.s==0)                  ){warning("There are zero values in the denominator variable VecX.s.")                 }
   VecEstTheta_k                       <- .C("Est_Ratio_Excluding_All_Elements",
                                              as.double(VecY.s),
                                              as.double(VecX.s),
